@@ -38,22 +38,22 @@ class OpenTicketsByUser(Feed):
         if obj['queue']:
             return _("Helpdesk: Open Tickets in queue %(queue)s for %(username)s") % {
                 'queue': obj['queue'].title,
-                'username': obj['user'].username,
+                'username': obj['user'].get_username(),
                 }
         else:
             return _("Helpdesk: Open Tickets for %(username)s") % {
-                'username': obj['user'].username,
+                'username': obj['user'].get_username(),
                 }
 
     def description(self, obj):
         if obj['queue']:
             return _("Open and Reopened Tickets in queue %(queue)s for %(username)s") % {
                 'queue': obj['queue'].title,
-                'username': obj['user'].username,
+                'username': obj['user'].get_username(),
                 }
         else:
             return _("Open and Reopened Tickets for %(username)s") % {
-                'username': obj['user'].username,
+                'username': obj['user'].get_username(),
                 }
 
     def link(self, obj):
@@ -90,7 +90,7 @@ class OpenTicketsByUser(Feed):
 
     def item_author_name(self, item):
         if item.assigned_to:
-            return item.assigned_to.username
+            return item.assigned_to.get_username()
         else:
             return _('Unassigned')
 
@@ -116,7 +116,7 @@ class UnassignedTickets(Feed):
 
     def item_author_name(self, item):
         if item.assigned_to:
-            return item.assigned_to.username
+            return item.assigned_to.get_username()
         else:
             return _('Unassigned')
 
@@ -168,7 +168,7 @@ class OpenTicketsByQueue(Feed):
 
     def item_author_name(self, item):
         if item.assigned_to:
-            return item.assigned_to.username
+            return item.assigned_to.get_username()
         else:
             return _('Unassigned')
 
